if {$argc < 7} {
    puts "vmd -dispdev text -e $argv0 -args psfPrefix pdbPrefix dcdPrefix xstPrefix selText timestep outPut"
    exit
}
set psfPrefix1 [lindex $argv 0]
set pdbPrefix [lindex $argv 1]
set psfPrefix2 [lindex $argv 2]
set dcdPrefix [lindex $argv 3]
set xstPrefix [lindex $argv 4]
set selText [lindex $argv 5]
set timestep [lindex $argv 6]
set outPut [lindex $argv 7]

## Load molecules
set psf1 $psfPrefix1.psf
set pdb $pdbPrefix.pdb
set psf2 $psfPrefix2.psf
set dcd $dcdPrefix.dcd

set REFID [mol load psf $psf1 pdb $pdb]
set ID [mol load psf $psf2 dcd $dcd]
set n [molinfo $ID get numframes] 
puts "  Loaded $n frames."

## Create selections for finding basepairs    
set AN "(resname ADE and name N1)"
set TH "(resname THY and name H3)"
set CN "(resname CYT and name N3)"
set GH "(resname GUA and name H1)"

set TN "(resname THY and name N3)"
set GN "(resname GUA and name N1)"

set ref1 [atomselect $REFID "$selText and ($AN or $CN)"]
set ref2 [atomselect $REFID "$selText and ($TH or $GH)"]
set ref3 [atomselect $REFID "$selText and ($TN or $GN)"]
set sel1 [atomselect $ID [$ref1 text]]
set sel2 [atomselect $ID [$ref2 text]]
set sel3 [atomselect $ID [$ref3 text]]

proc countBasepairs {sel1 sel2} {
    variable HtoN
    set cutoff 3.0
    set topmol [molinfo top]

    mol top [$sel1 molid]
    lassign [measure contacts $cutoff $sel1 $sel2] is js
    
    ## Check if angle is consistent with H-bond
    set bps 0
    foreach i $is j $js {
	set a [measure angle "$i $j $HtoN($j)"]
	if {$a > 140} {
	    incr bps
	}
    }

    mol top $topmol
    return $bps
}

foreach i [$ref2 get index] j [$ref3 get index] {
    set HtoN($i) $j
}
set numBps0 [countBasepairs $ref1 $ref2]

## Get time in nanoseconds
set t ""
set inStream [open ${xstPrefix}.xst r]
gets $inStream;  gets $inStream;
while {[gets $inStream line] > 0} {
    lappend t [expr [lindex $line 0] * $timestep * 1.0e-6]
}


foreach i [$sel2 get index] j [$sel3 get index] {
    set HtoN($i) $j
}

## Loop over frames
set ch [open $outPut a]
for {set f 0} {$f < $n} {incr f} {
    $sel1 frame $f
    $sel2 frame $f
    set numBps [countBasepairs $sel1 $sel2]
    puts $ch "[lindex $t $f] [expr {$numBps0-$numBps}]"
}
close $ch
exit
